1.16.3 — Rucio 1.2 documentation

# 1.16.3

## General

### Enhancements

- Consistency checks: Auditor is not able to handle dumps on non-SRM endpoint #429
- Core & Internals: dataset thread in kronos dies when RSE doesn’t exist #1184
- Infrastructure: Rework docker images for Kubernetes #1086
- Infrastructure: server and daemons container builds are failing caused by pip install #1190
- Transfers: Fixes for replica selection in conveyor #667

### Bugs

- Clients: rucio set-metadata returns status code 0 for non-existing DID #493
- Consistency checks: Auditor does not work with certain HTTPS dumps #367
- Core & Internals: DB exception occur after detach and attach DID repeatedly #1004
- Core & Internals: Credentials config/file should be optional not mandatory #1144
- Transfers: transfers: verify_checksum badly propagated #1219

## Clients

### Enhancements

- Clients: Raise Meaningful Exception When Protocol Fails To Get Checksum #1149
- Clients: clients: workaround url signature for rucio download until download-api is deployed #1208

### Bugs

- Clients: rucio erase with wildcards #406
- RSE Manager: RSE manager: remove .part from filename if adler32 is set and ignore_checksum is true #1185